### Version 0.2.9
- chore: change version calculation

### Version 0.2.9
- fix: change some blocks in __base.html template
- chore: update assets

### Version 0.2.8
- refactor: move all javascript code to typescript refactor: replace selectr with choices.js
- feat: add Path and Settings
- chore: add missing file .flake8

### Version 0.2.7

### Version 0.2.6
- fix: rename duplicate variable in .gitlab-ci.yml

### Version 0.2.5
- fix: replace packagr with pypi
- fix: add get_version function
- fix: update get_version()
- fix: update get_version() with PEP 440 specification
- fix: prevent crash on pip install
- fix: add get_templates_dir() function
- feat: add MANIFEST.in
- fix: include package data on install

### Version 0.2.4

### Version 0.2.3

### Version 0.2.2

### Version 0.2.1

### Version 0.2.0
- Initial code
- refactor(form_styling): Better widget detection
- feat: add pipenv and vscode configurations
- feat: add some settings for karvi app
- fix: move navbar content to base template
- fix: small type error in signup template
- style: add support for custom user menu
- style: enable navbar colapse on mobile
- refactor: drop jquery in favor of vanilla js
- chore: update yarn dependencies
- feat: add karvi.version to context
- chore: update karvi assest and configs
- chore: update karvi assets
- feat: add selectr support (work in progress)
- fix: load selectr on DOMContentLoaded
- style: change selectr classes to fit bulma style
- feat: configure selectr using html classes
- feat: add support for selectr widget config
- refactor: change access point to karvi_settings
- Add LICENSE
- refactor: move navbar block to different template
- chore: update yarn dependencies
- feat: add bulma carousel support
- chore: update yarn dependencies
